"use client"
import React, { useEffect, useState } from 'react'
import styles from './item.module.css'
import Input from '@/components/base/input/Input';
import closeIcon from '@/public/icons/red-x-10333.svg';
import Image from 'next/image';
export interface ItemProps {
    id: number;
    task: string;
    isCompleted: boolean;
    onClose: (id: number) => void;
    updateTask: (id: number, task: string, isCompleted: boolean) => void;
}

const Item: React.FC<ItemProps> = ({ task, isCompleted, onClose, updateTask, id }) => {
    const [isChecked, setisChecked] = useState(isCompleted)
    useEffect(() => {
        setisChecked(isCompleted)
    }, [isCompleted])

    const handleChange = async () => {
        const res: any = await updateTask(id, task, !isCompleted)
        if (res) {
            setisChecked(!isChecked)
        }
    }

    const handleItem = (e: React.ChangeEvent<HTMLInputElement>) => {
        updateTask(id, e.target.value, isCompleted)
    }

    const handleClose = () => {
        onClose(id)
    }

    return (
        <div className={styles.items}>
            <input type='checkbox' checked={isChecked} onChange={handleChange} className={styles.checkbox} />
            <Input placeholder='Enter item...' defaultValue={task} onBlur={handleItem} style={{
                border: 'none',
                boxShadow: 'none',
                padding: 0,
                color: 'gray',
                fontSize: '18px',
                textDecoration: isChecked ? 'line-through' : ''
            }} />
            <div className={styles.actions} onClick={handleClose} >

                <Image src={closeIcon} alt="" width={22} height={22} className={styles.closeIcon} />
            </div>
        </div>
    )
}

export default Item